=====================
WeatherAlerts README
=====================





PROJECT STATUS
===================
This module is a mess, a functional mess, but still a mess.... As I have time, I'm rewriting it and the 0.5.x
branch is much improved.


I've been working on a REST JSON webservice powered by this package, its a working prototype at the moment
but if you interested, let me know.


CURRENT BUILD STATUS:

As of 0.5.x this package has 100% test coverage, every commit is built and tested in both python 2 and python 3.


.. image:: http://ci.hznet.us/job/WeatherAlertsMaster/badge/icon



Documentation
==============
Please see http://weatheralerts.readthedocs.org for documentation

This project lives at `github.com/zebpalmer/WeatherAlerts <http://github.com/zebpalmer/WeatherAlerts>`_


License
---------
Version 0.5.x is being released under LGPLv3.


Install
---------
You can download and install/upgrade via PIP by runing:  ``pip install -U weatheralerts``


Author
--------
This module is maintained by Zeb Palmer, a Linux Systems Engineer and Professional Photographer who writes a bit of python at work and play.
See my other work at `ZebPalmer.com <http://www.zebpalmer.com>`_


